package com.safeway.pricing.handler;

import com.safeway.pricing.dto.CRCDetailsDTO;
import com.safeway.pricing.exception.GlobalErrorAttributes;
import com.safeway.pricing.model.FilterByDetails;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.web.reactive.function.server.ServerRequest;
import org.springframework.web.reactive.function.server.ServerResponse;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

import java.time.Duration;
import java.util.Arrays;
import java.util.List;

@Service
public class PricingHandler {

    public Mono<ServerResponse> getDefaultFilterDetails(ServerRequest serverRequest){

        Flux<FilterByDetails> filterByDetails = Flux.range(1,10)
                .delayElements(Duration.ofSeconds(1))
                .map(i -> FilterByDetails.builder()
                .category(Arrays.asList("3610-Traditional")).departments(Arrays.asList("314-Dairy"))
                                .groups(Arrays.asList("36-Refrigirator Dairy"))
                                .rog(Arrays.asList("VSOC"))
                                .priceAreas(Arrays.asList("VSOC-01"))
                                .storeGroups(Arrays.asList("51")).build());

        return ServerResponse.ok().contentType(MediaType.TEXT_EVENT_STREAM)
                .body(filterByDetails, FilterByDetails.class);

    }

    public Mono<ServerResponse> getCRCDetails(ServerRequest serverRequest) {

        Flux<CRCDetailsDTO> crcDetails = Flux.range(1,10).filter(i -> i == 2)
                .onErrorResume(e -> Mono.error(new RuntimeException("Error at Fetching Data2")))
                .map(i -> CRCDetailsDTO.builder().build());
        //throw new RuntimeException("Exception Testing");
       return ServerResponse.ok().contentType(MediaType.TEXT_EVENT_STREAM)
                .body(crcDetails,CRCDetailsDTO.class)
                .onErrorResume(e -> Mono.error(new RuntimeException("Error at Fetching Data")));
    }

}
