package com.safeway.pricing.safeway;

import com.safeway.pricing.config.SecurityConfig;
import com.safeway.pricing.handler.PricingHandler;
import com.safeway.pricing.model.FilterByDetails;
import com.safeway.pricing.router.AppRouterConfig;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.reactive.WebFluxTest;
import org.springframework.http.MediaType;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit.jupiter.SpringExtension;
import org.springframework.test.web.reactive.server.WebTestClient;
import reactor.core.publisher.Flux;
import reactor.test.StepVerifier;

import java.time.Duration;
import java.util.Arrays;

@ExtendWith(SpringExtension.class)
@ContextConfiguration(classes={AppRouterConfig.class, PricingHandler.class,SecurityConfig.class})
@WebFluxTest
class SafewayPricingPodApplicationTests {

	@Autowired
	private WebTestClient webTestClient;

     @BeforeEach
	void setWebTestClient(){
		webTestClient=webTestClient.mutate()
				.responseTimeout(Duration.ofMillis(30000))
				.build();
	}

	@Test
	void contextLoads() {
	}

	@Test
	void expectOKResponse_WhenAccessNotSecuredURL() throws Exception {

		FilterByDetails filterByDetails=FilterByDetails.builder()
				.category(Arrays.asList("3610-Traditional")).departments(Arrays.asList("314-Dairy"))
				.groups(Arrays.asList("36-Refrigirator Dairy"))
				.rog(Arrays.asList("VSOC"))
				.priceAreas(Arrays.asList("VSOC-01"))
				.storeGroups(Arrays.asList("51")).build();

		Flux<FilterByDetails> flux=webTestClient.get().uri("/getDefaultFilterDetails")
				.accept(MediaType.TEXT_EVENT_STREAM)
				.exchange()
				.expectStatus()
				.isOk()
				.returnResult(FilterByDetails.class).getResponseBody();


		StepVerifier.create(flux).expectNextCount(10).verifyComplete();
	}

	@Test
	public void authenticationTest(){
		Flux<FilterByDetails> flux=webTestClient.get().uri("/api/getCRCDetails2")
				.accept(MediaType.TEXT_EVENT_STREAM)
				.exchange()
				.expectStatus()
				.is3xxRedirection()
				.returnResult(FilterByDetails.class).getResponseBody();
	}





}
